@@ -3,7 +3,7 @@ package Pod::Simple::Search;
 use strict;
 
 use vars qw($VERSION $MAX_VERSION_WITHIN $SLEEPY);
-$VERSION = '3.29_3';   ## Current version of this package
+$VERSION = '3.29_5';   ## Current version of this package
 
 BEGIN { *DEBUG = sub () {0} unless defined &DEBUG; }   # set DEBUG level
 use Carp ();
@@ -51,7 +51,6 @@ sub survey {
 
   $self->_expand_inc( \@search_dirs );
 
-
   $self->{'_scan_count'} = 0;
   $self->{'_dirs_visited'} = {};
   $self->path2name( {} );
@@ -206,20 +205,24 @@ sub _make_search_callback {
         
     # Put off until as late as possible the expense of
     #  actually reading the file:
-    if( m/\.pod\z/is ) {
-      # just assume it has pod, okay?
-    } else {
-      $progress and $progress->reach($self->{'_scan_count'}, "Scanning $file");
-      return unless $self->contains_pod( $file );
-    }
+    $progress and $progress->reach($self->{'_scan_count'}, "Scanning $file");
+    return unless $self->contains_pod( $file );
     ++ $self->{'_scan_count'};
 
     # Or finally take note of it:
-    if( $name2path->{$name} ) {
+    if( my $seen = $name2path->{$name} ) {
       $verbose and print
        "Duplicate POD found (shadowing?): $name ($file)\n",
        "    Already seen in ",
        join(' ', grep($path2name->{$_} eq $name, keys %$path2name)), "\n";
+      # Prefer .pod over .pm, and .pm over .pl.
+      if ($seen !~ /[.]pod$/) {
+          if ($file =~ /[.]pod$/) {
+              $name2path->{$name} = $file;
+          } else {
+              $name2path->{$name} = $file if $seen !~ /[.]pm$/ && $file =~ /[.]pm$/;
+          }
+      }
     } else {
       $name2path->{$name} = $file; # Noting just the first occurrence
     }
@@ -565,7 +568,7 @@ sub find {
 
     foreach my $ext ('', '.pod', '.pm', '.pl') {   # possible extensions
       my $fullext = $fullname . $ext;
-      if( -f $fullext  and  $self->contains_pod( $fullext ) ){
+      if( -f $fullext and  $self->contains_pod( $fullext ) ) {
         print "FOUND: $fullext\n" if $verbose;
         return $fullext;
       }
@@ -990,6 +993,7 @@ with default attribute values is used.
 
 Returns true if the supplied filename (not POD module) contains some Pod
 documentation.
+
 =head1 SUPPORT
 
 Questions or discussion about POD and Pod::Simple should be sent to the
